@@ -1,9 +1,9 @@
 package Sah::PSchema::perl::modname;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-02-02'; # DATE
+our $DATE = '2021-02-06'; # DATE
 our $DIST = 'Sah-PSchemas-Perl'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use strict;
 use warnings;
@@ -18,11 +18,17 @@ sub meta {
                 schema => 'perl::modname*',
                 default => '',
             },
+            ns_prefixes => {
+                schema => 'perl::modname*',
+            },
             complete_recurse => {
                 summary => 'Whether completion should recurse',
                 schema => 'bool*',
             },
         },
+        args_rels => {
+            choose_one => [qw/ns_prefix ns_prefixes/],
+        },
     };
 }
 
@@ -30,7 +36,11 @@ sub get_schema {
     my ($class, $args, $merge) = @_;
 
     return ['perl::modname', {
-        'x.completion' => ['perl_modname' => {ns_prefix=>$args->{ns_prefix}, recurse=>$args->{complete_recurse}, recurse_matching=>'all-at-once'}],
+        'x.completion' => ['perl_modname' => {
+            ($args->{ns_prefixes} ? (ns_prefixes => $args->{ns_prefixes}) : (ns_prefix => $args->{ns_prefix})),
+            recurse=>$args->{complete_recurse},
+            recurse_matching=>'all-at-once',
+        }],
         %{ $merge || {} },
     }, {}];
 }
@@ -50,7 +60,7 @@ Sah::PSchema::perl::modname - Perl module name (parameterized)
 
 =head1 VERSION
 
-This document describes version 0.006 of Sah::PSchema::perl::modname (from Perl distribution Sah-PSchemas-Perl), released on 2021-02-02.
+This document describes version 0.007 of Sah::PSchema::perl::modname (from Perl distribution Sah-PSchemas-Perl), released on 2021-02-06.
 
 =head1 DESCRIPTION
 
