@@ -1,9 +1,9 @@
 package Sah::PSchema::perl::modname_with_optional_args;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-02-02'; # DATE
+our $DATE = '2021-02-06'; # DATE
 our $DIST = 'Sah-PSchemas-Perl'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use strict;
 use warnings;
@@ -18,11 +18,17 @@ sub meta {
                 schema => 'perl::modname*',
                 default => '',
             },
+            ns_prefixes => {
+                schema => 'perl::modname*',
+            },
             complete_recurse => {
                 summary => 'Whether completion should recurse',
                 schema => 'bool*',
             },
         },
+        args_rels => {
+            choose_one => [qw/ns_prefix ns_prefixes/],
+        },
     };
 }
 
@@ -31,10 +37,15 @@ sub get_schema {
 
     return ["perl::modname_with_optional_args" => {
         'x.perl.coerce_rules' => [
-            ['From_str::normalize_perl_modname' => {ns_prefix=>$args->{ns_prefix}}],
+            'From_str::normalize_perl_modname',
         ],
 
-        'x.completion' => ['perl_modname' => {ns_prefix=>$args->{ns_prefix}, recurse=>$args->{complete_recurse}, recurse_matching=>'all-at-once'}],
+        'x.completion' => ['perl_modname' => {
+            ($args->{ns_prefixes} ? (ns_prefixes => $args->{ns_prefixes}) : (ns_prefix => $args->{ns_prefix})),
+            recurse=>$args->{complete_recurse},
+            recurse_matching=>'all-at-once',
+        }],
+
         %{ $merge || {} },
     }, {}];
 }
@@ -54,7 +65,7 @@ Sah::PSchema::perl::modname_with_optional_args - Perl module name with optional
 
 =head1 VERSION
 
-This document describes version 0.006 of Sah::PSchema::perl::modname_with_optional_args (from Perl distribution Sah-PSchemas-Perl), released on 2021-02-02.
+This document describes version 0.007 of Sah::PSchema::perl::modname_with_optional_args (from Perl distribution Sah-PSchemas-Perl), released on 2021-02-06.
 
 =head1 DESCRIPTION
 
